==> chromium-browser_13.0.782.220~r99552.orig.tar.bz2: chromium-13.0.782.220~r99552/src/chrome/browser/tabs/tab_strip_model_observer.cc <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/tabs/tab_strip_model_observer.h"

void TabStripModelObserver::TabInsertedAt(TabContentsWrapper* contents,
                                          int index,
                                          bool foreground) {
}

void TabStripModelObserver::TabClosingAt(TabStripModel* tab_strip_model,
                                         TabContentsWrapper* contents,
                                         int index) {
}

void TabStripModelObserver::TabDetachedAt(TabContentsWrapper* contents,
                                          int index) {
}

void TabStripModelObserver::TabDeselected(TabContentsWrapper* contents) {
}

void TabStripModelObserver::ActiveTabChanged(TabContentsWrapper* old_contents,
                                             TabContentsWrapper* new_contents,
                                             int index,
                                             bool user_gesture) {
}

void TabStripModelObserver::TabMoved(TabContentsWrapper* contents,
                                     int from_index,
                                     int to_index) {
}

void TabStripModelObserver::TabChangedAt(TabContentsWrapper* contents,
                                         int index,
                                         TabChangeType change_type) {
}

void TabStripModelObserver::TabReplacedAt(TabStripModel* tab_strip_model,
                                          TabContentsWrapper* old_contents,
                                          TabContentsWrapper* new_contents,
                                          int index) {
}

void TabStripModelObserver::TabPinnedStateChanged(TabContentsWrapper* contents,
                                                  int index) {
}

void TabStripModelObserver::TabMiniStateChanged(TabContentsWrapper* contents,
                                                int index) {
}

void TabStripModelObserver::TabBlockedStateChanged(TabContentsWrapper* contents,
                                                   int index) {
}

void TabStripModelObserver::TabStripEmpty() {}

void TabStripModelObserver::TabStripModelDeleted() {}

void TabStripModelObserver::ActiveTabClicked(int index) {}

==> chromium-browser_15.0.874.121~r109964.orig.tar.bz2: chromium-15.0.874.121~r109964/src/chrome/browser/tabs/tab_strip_model_observer.cc <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/tabs/tab_strip_model_observer.h"

void TabStripModelObserver::TabInsertedAt(TabContentsWrapper* contents,
                                          int index,
                                          bool foreground) {
}

void TabStripModelObserver::TabClosingAt(TabStripModel* tab_strip_model,
                                         TabContentsWrapper* contents,
                                         int index) {
}

void TabStripModelObserver::TabDetachedAt(TabContentsWrapper* contents,
                                          int index) {
}

void TabStripModelObserver::TabDeactivated(TabContentsWrapper* contents) {
}

void TabStripModelObserver::ActiveTabChanged(TabContentsWrapper* old_contents,
                                             TabContentsWrapper* new_contents,
                                             int index,
                                             bool user_gesture) {
}

void TabStripModelObserver::TabSelectionChanged(
    const TabStripSelectionModel& model) {
}

void TabStripModelObserver::TabMoved(TabContentsWrapper* contents,
                                     int from_index,
                                     int to_index) {
}

void TabStripModelObserver::TabChangedAt(TabContentsWrapper* contents,
                                         int index,
                                         TabChangeType change_type) {
}

void TabStripModelObserver::TabReplacedAt(TabStripModel* tab_strip_model,
                                          TabContentsWrapper* old_contents,
                                          TabContentsWrapper* new_contents,
                                          int index) {
}

void TabStripModelObserver::TabPinnedStateChanged(TabContentsWrapper* contents,
                                                  int index) {
}

void TabStripModelObserver::TabMiniStateChanged(TabContentsWrapper* contents,
                                                int index) {
}

void TabStripModelObserver::TabBlockedStateChanged(TabContentsWrapper* contents,
                                                   int index) {
}

void TabStripModelObserver::TabStripEmpty() {}

void TabStripModelObserver::TabStripModelDeleted() {}

void TabStripModelObserver::ActiveTabClicked(int index) {}
